<?php
/**
 *  @package Ibamu
 */
/*
Plugin Name: Ibamu
Plugin URI: https://ibamu.es/
Description: Plugin todo en uno desarrollado por Ibamu. Incluye las funcionalidades para ayudar a tu web a cumplir con las normativas RGPD, LOPDGDD, LSSI, LGDCU.
Version: 1.0.7
Author: ibamu
Author URI: https://profiles.wordpress.org/ibamu/
Tags: cookies, cookie law, cookie policy, cookie banner, privacy policy, cookie consent, privacy, gdpr, eprivacy
License: GPLv2 or later
Text Domain: Ibamu
*/

if (! defined('ABSPATH')){
    die;
}

function ibamu_settings_init() {
    // Register a new setting for "ibamu" page.
    register_setting('ibamu', 'ibamu_options');

    // Register a new section in the "ibamu" page.
    add_settings_section(
        'ibamu_section_developers',
        "", "",
        'ibamu'
    );

    // Register a new field in the "ibamu_section_developers" section, inside the "ibamu" page.
    add_settings_field(
        'ibamu_widget_uuid',
        __( 'Plugin ID', 'ibamu-plugin-domain' ),
        'ibamu_widget_uuid_render',
        'ibamu',
        'ibamu_section_developers',
        array(
            'label_for'         => 'ibamu_widget_uuid',
            'class'             => 'ibamu_row',
            'ibamu_custom_data' => 'custom',
        )
    );

    add_settings_field(
        'ibamu_api_key',
        __( 'Clave', 'ibamu-plugin-domain' ),
        'ibamu_api_key_render',
        'ibamu',
        'ibamu_section_developers',
        array(
            'label_for'         => 'ibamu_api_key',
            'class'             => 'ibamu_row',
            'ibamu_custom_data' => 'custom',
        )
    );
}

wp_enqueue_style('ibamu-admin', plugins_url('/css/ibamu.css', __FILE__ ));

/**
 * Register our ibamu_settings_init to the admin_init action hook.
 */
add_action('admin_init', 'ibamu_settings_init');


function ibamu_widget_uuid_render( $args ) {
    ?>
    <input
        id="<?php echo esc_attr( $args['label_for'] ); ?>"
        data-custom="<?php echo esc_attr( $args['ibamu_custom_data'] ); ?>"
        name="ibamu_options[<?php echo esc_attr( $args['label_for'] ); ?>]"
        value="<?php echo esc_attr( get_option('ibamu_options')['ibamu_widget_uuid'] ); ?>"
        placeholder="Widget id"
        class="regular-text"
        type="text"
        required>
    </input>
    <p class="description">Introduce el Plugin ID</p>
    <?php
}

function ibamu_api_key_render( $args ) {
    ?>
    <input
        id="<?php echo esc_attr( $args['label_for'] ); ?>"
        data-custom="<?php echo esc_attr( $args['ibamu_custom_data'] ); ?>"
        name="ibamu_options[<?php echo esc_attr( $args['label_for'] ); ?>]"
        value="<?php echo esc_attr( get_option('ibamu_options')['ibamu_api_key'] ); ?>"
        placeholder="API key"
        class="regular-text"
        type="text"
        required>
    </input>
    <p class="description">Introduce la Clave API</p>
    <?php
}

/**
 * Add the top level menu page.
 */
function ibamu_options_page() {
    add_menu_page(
        'ibamu',
        'Ibamu',
        'manage_options',
        'ibamu',
        'ibamu_options_page_html',
        'https://cdn.ibamu.es/static/home/favicon-16x16.png'
    );
}


/**
 * Register our ibamu_options_page to the admin_menu action hook.
 */
add_action('admin_menu', 'ibamu_options_page');


/**
 * Top level menu callback function
 */
function ibamu_options_page_html() {
    // check user capabilities
    if ( ! current_user_can('manage_options') ) {
        return;
    }

    // add error/update messages

    // check if the user have submitted the settings
    // WordPress will add the "settings-updated" $_GET parameter to the url
    if ( isset( $_GET['settings-updated'] ) ) {
        // add settings saved message with the class of "updated"
        add_settings_error('ibamu_messages', 'ibamu_message', esc_html(__('Datos guardados correctamente'), 'ibamu-plugin-domain'), 'updated');
    }

    // show error/update messages
    esc_html(settings_errors('ibamu_messages'));
    ?>
    <div class="wrap">
        <div id="ibamu-header">
            <a class="ibamu-link" href="http://ibamu.es" title="ibamu" target="_blank">
                <img height="40" width="128" class="navbar-brand-dark rotate-logo" src="https://cdn.ibamu.es/static/home/logo_dark.png" alt="textos legales web">
            </a>
        </div>

        <p class="ibamu-text">
        Plugin todo en uno desarrollado por Ibamu. Incluye las funcionalidades para ayudar a tu web a cumplir con las normativas RGPD, LOPDGDD, LSSI, LGDCU.
        </p>

        <p class="ibamu-text">
        Este plugin es la manera mas sencilla de adaptar tu sitio Wordpress a Ibamu.
        El plugin se encargará de bloquear y reactivar las cookies una vez el usuario haya dado su consentimiento. Además, también incluirá los documentos legales necesarios en el footer de tu web.
        </p>

        <p class="ibamu-text">
        Puedes configurar el comportamiento y estilos del plugin desde tu panel de usuario de <a class="ibamu-url" href="https://ibamu.es" target="_blank">https://ibamu.es</a>
        </p>

        <p class="ibamu-text">
            <span class="ibamu-title">¿Qué tiene que tener una web para que cumpla con la normativa?</span>
            <br>
            <a href="https://ibamu.es/blog/que-tiene-que-tener-una-web-para-que-cumpla-con-la-normativa-espanola/" class="ibamu-url" target="_blank">https://ibamu.es/blog/que-tiene-que-tener-una-web-para-que-cumpla-con-la-normativa-espanola/</a>
        </p>

        <p class="ibamu-text">
            <span class="ibamu-title">¿Como tiene que ser el banner de cookies de una página web?</span>
            <br>
            <a href="https://ibamu.es/blog/que-tiene-que-tener-una-web-para-que-cumpla-con-la-normativa-espanola/" class="ibamu-url" target="_blank">https://ibamu.es/blog/como-tiene-que-ser-el-banner-de-cookies-de-una-pagina-web/</a>
        </p>

        <h2>Configuración</h2>

        <p class="ibamu-text">
        Para configurar correctamente el plugin necesitarás rellenar este formulario con los valores que encontrarás en tu perfil de usuario de <a class="ibamu-url" href="https://ibamu.es" target="_blank">https://ibamu.es</a>
        </p>

        <form action="options.php" method="post">
            <?php
            esc_html(settings_fields('ibamu'));
            esc_html(do_settings_sections('ibamu'));
            esc_html(submit_button(__('Guardar', 'ibamu-plugin-domain')));
            ?>
        </form>
    </div>
    <?php
}

/**
 * Enqueue ibamu-widget.js with context configuration
 */
add_action('wp_enqueue_scripts', 'ibamu_include_widget');
function ibamu_include_widget() {
    wp_enqueue_script('ibamu-widget-js', plugins_url('/ibamu-widget.js', __FILE__ ));

    $options = get_option('ibamu_options');
    $ibamuWidgetConfig = array(
        'ibamu_widget_uuid' => $options["ibamu_widget_uuid"],
        'ibamu_api_key' => $options["ibamu_api_key"],
    );

    wp_localize_script('ibamu-widget-js', 'ibamu_widget_config', $ibamuWidgetConfig);
}
?>
